Documentation
¶
Overview ¶
Package keystore provides encrypted on-disk storage for identity key material. The keystore file is encrypted with AES-256-GCM using a key derived from a user-supplied passphrase via HKDF-SHA256.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrNotFound is returned when an address is not in the keystore. ErrNotFound = errors.New("keystore: identity not found") // ErrDecryptionFailed is returned when the passphrase is wrong. ErrDecryptionFailed = errors.New("keystore: decryption failed (wrong passphrase?)") )
Functions ¶
This section is empty.
Types ¶
type Keystore ¶
type Keystore struct {
// contains filtered or unexported fields
}
Keystore manages encrypted identity key material on disk.
func New ¶
New creates a Keystore backed by the file at path. The passphrase is used to derive the encryption key. The file is created on first write.
Click to show internal directories.
Click to hide internal directories.